package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcCy;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcXtjcMapper;
import com.ruoyi.tcZz.domain.TcXtjc;
import com.ruoyi.tcZz.service.ITcXtjcService;

/**
 * 系统监测Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Service
public class TcXtjcServiceImpl implements ITcXtjcService 
{
    @Autowired
    private TcXtjcMapper tcXtjcMapper;

    /**
     * 查询系统监测
     * 
     * @param id 系统监测主键
     * @return 系统监测
     */
    @Override
    public TcXtjc selectTcXtjcById(Long id)
    {
        return tcXtjcMapper.selectTcXtjcById(id);
    }

    /**
     * 查询系统监测列表
     * 
     * @param tcXtjc 系统监测
     * @return 系统监测
     */
    @Override
    public List<TcXtjc> selectTcXtjcList(TcXtjc tcXtjc)
    {
        return tcXtjcMapper.selectTcXtjcList(tcXtjc);
    }

    /**
     * 新增系统监测
     * 
     * @param tcXtjc 系统监测
     * @return 结果
     */
    @Override
    public int insertTcXtjc(TcXtjc tcXtjc)
    {
        tcXtjc.setCreateTime(DateUtils.getNowDate());
        return tcXtjcMapper.insertTcXtjc(tcXtjc);
    }

    /**
     * 修改系统监测
     * 
     * @param tcXtjc 系统监测
     * @return 结果
     */
    @Override
    public int updateTcXtjc(TcXtjc tcXtjc)
    {
        tcXtjc.setUpdateTime(DateUtils.getNowDate());
        return tcXtjcMapper.updateTcXtjc(tcXtjc);
    }

    /**
     * 批量删除系统监测
     * 
     * @param ids 需要删除的系统监测主键
     * @return 结果
     */
    @Override
    public int deleteTcXtjcByIds(Long[] ids)
    {
        return tcXtjcMapper.deleteTcXtjcByIds(ids);
    }

    /**
     * 删除系统监测信息
     * 
     * @param id 系统监测主键
     * @return 结果
     */
    @Override
    public int deleteTcXtjcById(Long id)
    {
        return tcXtjcMapper.deleteTcXtjcById(id);
    }

    @Override
    public String importUser(List<TcXtjc> tcXtjcList) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcXtjcList.isEmpty()) {
            for (TcXtjc tcXtjc : tcXtjcList) {
                tcXtjcMapper.insertTcXtjc(tcXtjc);
            }
            successMsg.append("导入成功");
        }

        return successMsg.toString();

    }

    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcXtjcMapper.updateByisStatus(isStatus,ids);
    }
}
